library test.decoding;

import 'package:test/test.dart';
import 'package:jaguar_jwt/jaguar_jwt.dart';

final key = 'secret';

main() {
  group('Decoding', () {
    test('Nopayload', () {
      final String token =
          r'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJhdWQiOlsiYWRtaW4iLCJzdHVkZW50cyJdLCJleHAiOjg2NDAwLCJpYXQiOjE0ODE4NDI4MDAsImlzcyI6InRlamEiLCJzdWIiOiIxMjM0NTY3ODkwIn0=.xtJbJ4lurm4HnflBN5V2LVamfqc3RK8lo20lRv_ffNw=';

      final JwtClaim claimSet = verifyJwtHS256Signature(token, key);

      expect(claimSet.issuer, equals('teja'));
      expect(claimSet.subject, "1234567890");
      expect(claimSet.audience, equals(["admin", "students"]));
      expect(claimSet.payload, isEmpty);
      expect(claimSet.issuedAt,
          new DateTime.fromMillisecondsSinceEpoch(1481842800000, isUtc: true));
      expect(
          claimSet.expiry,
          new DateTime.fromMillisecondsSinceEpoch(1481842800000, isUtc: true)
              .add(new Duration(days: 1)));
    });

    test('With payload', () {
      String token =
          r'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJhdWQiOlsiYWRtaW4iLCJzdHVkZW50cyJdLCJleHAiOjg2NDAwLCJpYXQiOjE0ODE4NDI4MDAsImlzcyI6InRlamEiLCJwbGQiOnsiayI6InYifSwic3ViIjoiMTIzNDU2Nzg5MCJ9.FniGPl78JT0AkqAVw9CR_lNE1xR31FPqtzYuL513dlE=';
      final JwtClaim claimSet = verifyJwtHS256Signature(token, key);
      expect(claimSet.issuer, equals('teja'));
      expect(claimSet.audience, equals(["admin", "students"]));
      expect(claimSet.payload, equals({"k": "v"}));
      expect(claimSet.subject, "1234567890");
      expect(claimSet.issuedAt,
          new DateTime.fromMillisecondsSinceEpoch(1481842800000, isUtc: true));
      expect(
          claimSet.expiry,
          new DateTime.fromMillisecondsSinceEpoch(1481842800000, isUtc: true)
              .add(new Duration(days: 1)));
    });
  });
}
